Index: content/renderer/gpu/renderer_gl_context.h |
diff --git a/content/renderer/gpu/renderer_gl_context.h b/content/renderer/gpu/renderer_gl_context.h |
index b3a8f74b26e670e15a6e394a4b5a3132b0da5545..abd8246d75f1f8eb9678f32496e3bd461377900a 100644 |
--- a/content/renderer/gpu/renderer_gl_context.h |
+++ b/content/renderer/gpu/renderer_gl_context.h |
@@ -16,6 +16,7 @@ |
#include "base/memory/weak_ptr.h" |
#include "base/threading/non_thread_safe.h" |
#include "build/build_config.h" |
+#include "ui/gfx/gl/gl_surface.h" |
#include "ui/gfx/gl/gpu_preference.h" |
#include "ui/gfx/native_widget_types.h" |
#include "ui/gfx/size.h" |
@@ -159,8 +160,8 @@ class RendererGLContext : public base::SupportsWeakPtr<RendererGLContext>, |
// task whether the echo succeeds or not. |
bool Echo(const base::Closure& task); |
- // Sends an IPC message with the new state of surface visibility |
- bool SetSurfaceVisible(bool visibility); |
+ // Sends an IPC message with the new state of resource usage |
+ bool SetResourceUsage(gfx::GLSurface::ResourceUsage resourceUsage); |
// TODO(gman): Remove this |
void DisableShaderTranslation(); |